<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Hide Price Hyva Compatibility
 */

namespace Amasty\HidePriceHyva\Model\BlockRender\ProductPage;

use Amasty\HidePrice\Helper\Data;
use Amasty\HidePrice\Model\ConfigProvider;
use Amasty\HidePriceHyva\Model\BlockRender\AbstractBlockRender;

class AddToCart extends AbstractBlockRender
{
    /**
     * @var ConfigProvider
     */
    private ConfigProvider $configProvider;

    /**
     * @var Data
     */
    private Data $helper;

    public function __construct(
        ConfigProvider $configProvider,
        Data $helper
    ) {
        $this->configProvider = $configProvider;
        $this->helper = $helper;
    }

    public function isApplicable(string $blockName): bool
    {
        return $blockName === 'product.info.addtocart' && $this->configProvider->isHideAddToCart();
    }

    public function render(): string
    {
        if (empty($this->html)) {
            return $this->html;
        }

        $html = trim(
            preg_replace('#<button.*?id="product-addtocart-button".*?</button>#s', '', $this->html)
        );

        return $this->helper->getNewAddToCartHtml($this->product) . $html;
    }
}
