<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Hide Price Hyva Compatibility
 */

namespace Amasty\HidePriceHyva\Plugin\Catalog\Block\Product\View;

use Amasty\HidePrice\Helper\Data;
use Amasty\HidePrice\Model\ConfigProvider;
use Amasty\HidePriceHyva\Model\BlockRenderPool;
use Hyva\Theme\Service\CurrentTheme;
use Magento\Catalog\Block\Product\View;

class ResolveRender
{
    /**
     * @var Data
     */
    private Data $helper;

    /**
     * @var CurrentTheme
     */
    private CurrentTheme $currentTheme;

    /**
     * @var BlockRenderPool
     */
    private BlockRenderPool $blockRenderPool;

    public function __construct(
        CurrentTheme $currentTheme,
        BlockRenderPool $blockRenderPool,
        Data $helper
    ) {
        $this->currentTheme = $currentTheme;
        $this->blockRenderPool = $blockRenderPool;
        $this->helper = $helper;
    }

    public function afterGetChildHtml(View $subject, string $result, ?string $blockName = null): string
    {
        if ($blockName === null
            || !$this->currentTheme->isHyva()
            || !$this->helper->isModuleEnabled()
            || !$this->helper->isApplied($subject->getProduct())
        ) {
            return $result;
        }

        return $this->blockRenderPool->render($subject->getProduct(), $result, $blockName);
    }
}
