<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Hide Price Hyva Compatibility
 */

namespace Amasty\HidePriceHyva\Plugin\HidePrice\Helper\Data;

use Amasty\HidePrice\Helper\Data;
use Amasty\HidePrice\Model\Source\ReplaceButton;
use Amasty\HidePrice\Model\ConfigProvider;
use Hyva\Theme\Service\CurrentTheme;
use Magento\Catalog\Api\Data\ProductInterface;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\LayoutInterface;
use Amasty\HidePriceHyva\Block\PopupDispatcher;

class InjectPopupTemplate
{
    /**
     * @var ConfigProvider
     */
    private ConfigProvider $configProvider;

    /**
     * @var LayoutInterface
     */
    private $layout;

    /**
     * @var CurrentTheme
     */
    private CurrentTheme $currentTheme;

    public function __construct(
        ConfigProvider $configProvider,
        LayoutInterface $layout,
        CurrentTheme $currentTheme
    ) {
        $this->configProvider = $configProvider;
        $this->layout = $layout;
        $this->currentTheme = $currentTheme;
    }

    /**
     * @param Data $subject
     * @param string $html
     * @param ProductInterface|null $product
     * @param array|null $productData
     * @return string
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function afterGetNewAddToCartHtml(
        Data $subject,
        string $html,
        ?ProductInterface $product = null,
        ?array $productData = null
    ): string {
        if (!$this->currentTheme->isHyva()) {
            return $html;
        }

        $html = $this->removeScriptTags($html);

        switch ($this->configProvider->getReplaceButtonType()) {
            case ReplaceButton::HIDE_PRICE_POPUP:
                $productId = $product === null ? (int)$productData['id'] : (int)$product->getId();
                $productName = $product === null ? (string)$productData['name'] : (string)$product->getName();
                $html .= $this->getPopupHtml($productId, $productName);
                break;
            case ReplaceButton::CUSTOM_FORM:
                $html .= $this->layout->createBlock(Template::class)
                    ->setTemplate('Amasty_HidePriceHyva::product/popup/customform-dispatcher.phtml')
                    ->toHtml();
                break;
        }

        return $html;
    }

    public function afterGetNewPriceHtmlBox(
        Data $subject,
        string $html,
        ?ProductInterface $product = null
    ): string {
        if (!$this->currentTheme->isHyva()) {
            return $html;
        }

        $html = $this->removeScriptTags($html);
        $html .= $this->getDummyPriceContainer();

        if ($this->configProvider->getHidePriceLink() === $subject::HIDE_PRICE_POPUP_IDENTIFICATOR) {
            $html .= $this->getPopupHtml((int)$product->getId(), (string)$product->getName());
        }

        return $html;
    }

    private function getPopupHtml(int $productId, string $productName): string
    {
        $popupBlock = $this->layout->createBlock(PopupDispatcher::class);
        $popupBlock->setProductId($productId);
        $popupBlock->setProductName($productName);

        return $popupBlock->toHtml();
    }

    private function removeScriptTags(string $html): string
    {
        return preg_replace('#<script(.*?)>(.*?)</script>#is', '', $html);
    }

    /**
     * Prevent console errors on swatch change
     *
     * @return string
     */
    private function getDummyPriceContainer(): string
    {
        return '<div class="normal-price hidden"><span class="price-label"></span></div>';
    }
}
