<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Hide Price Hyva Compatibility
 */

namespace Amasty\HidePriceHyva\ViewModel;

use Amasty\Customform\Block\Form;
use Amasty\HidePrice\Model\Source\ReplaceButton;
use Amasty\HidePrice\Model\ConfigProvider;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Framework\Module\Manager;
use Magento\Framework\View\LayoutInterface;

class CustomFormPopup implements ArgumentInterface
{
    /**
     * @var ConfigProvider
     */
    private ConfigProvider $configProvider;

    /**
     * @var Manager
     */
    private Manager $moduleManager;

    /**
     * @var LayoutInterface
     */
    private LayoutInterface $layout;

    public function __construct(
        ConfigProvider $configProvider,
        Manager $moduleManager,
        LayoutInterface $layout
    ) {
        $this->configProvider = $configProvider;
        $this->moduleManager = $moduleManager;
        $this->layout = $layout;
    }

    public function getFormHtml(): string
    {
        return $this->layout->createBlock(
            Form::class,
            '',
            [
                'data' => [
                    'form_id' => $this->configProvider->getCustomFormId()
                ]
            ]
        )->toHtml();
    }

    public function isNeedShow(): bool
    {
        return $this->moduleManager->isEnabled('Amasty_Customform')
            && $this->configProvider->getReplaceButtonType() == ReplaceButton::CUSTOM_FORM;
    }
}
