<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Hide Price Hyva Compatibility
 */

namespace Amasty\HidePriceHyva\ViewModel;

use Amasty\HidePrice\Model\ConfigProvider;
use Magento\Customer\Model\SessionFactory as CustomerSessionFactory;
use Magento\Customer\Model\Session as CustomerSession;
use Magento\Framework\UrlInterface;
use Magento\Framework\View\Element\Block\ArgumentInterface;

class Popup implements ArgumentInterface
{
    /**
     * @var CustomerSession
     */
    private CustomerSession $customerSession;

    /**
     * @var UrlInterface
     */
    private UrlInterface $urlBuilder;

    /**
     * @var ConfigProvider
     */
    private ConfigProvider $configProvider;

    public function __construct(
        CustomerSessionFactory $customerSessionFactory,
        UrlInterface $urlBuilder,
        ConfigProvider $configProvider
    ) {
        $this->customerSession = $customerSessionFactory->create();
        $this->urlBuilder = $urlBuilder;
        $this->configProvider = $configProvider;
    }

    public function getCustomerName(): string
    {
        return trim($this->customerSession->getCustomer()->getName() ?? '');
    }

    public function getCustomerEmail(): string
    {
        return $this->customerSession->getCustomer()->getEmail() ?? '';
    }

    public function getCustomerPhone(): string
    {
        return $this->customerSession->getCustomer()->getPhone() ?? '';
    }

    public function getAddRequestUrl(): string
    {
        return $this->urlBuilder->getUrl('amasty_hide_price/request/add');
    }

    public function isGDPREnabled(): bool
    {
        return $this->configProvider->isGDPREnabled();
    }

    public function getGDPRText(): string
    {
        return $this->configProvider->getGDPRText();
    }
}
